DELETE FROM report_sql WHERE computer={?computer};

-- NUM19 vrsta zapisa (1=detail, 4= churn)

-- NUM19=1:
-- NUM1  numerini mesec
-- NUM2  leto
-- STR1  3-mestni naziv meseca
-- DATE1 prvi dan meseca
-- DATE2 zadnji dan meseca
-- STR2  kategorija
-- STR3  ifra kategorije
-- NUM3  sort iz M_NNKATEG
-- NUM4  tevilo novih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM5  tevilo podaljanih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM6  tevilo poteklih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM7  tevilo prekinjenih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM14 tevilo novih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji
-- NUM15 tevilo podaljanih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji
-- NUM16 tevilo poteklih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji
-- NUM17 tevilo prekinjenih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji

-- Lapse Annual:
-- NUM8  lapse rate letnih (trajanje >= 365 dni) pogodb
-- NUM3  vrednost 0 (zaradi grupiranja in izloanja vrstic v cross-tabu)

-- Lapse Seasonal:
-- NUM9  lapse rate sezonskih (trajanje > 180 in < 365 dni) pogodb
-- NUM3  vrednost 0 (zaradi grupiranja in izloanja vrstic v cross-tabu)

-- NUM19=4:
-- STR2  kategorija
-- STR3  ifra kategorije
-- NUM3  sort iz M_NNKATEG
-- NUM4  tevilo novih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM5  tevilo podaljanih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM6  tevilo poteklih + prekinjenih letnih (trajanje >= 365 dni) pogodb v posamezni kategoriji
-- NUM14 tevilo novih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji
-- NUM15 tevilo podaljanih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji
-- NUM16 tevilo poteklih + prekinjenih sezonskih (trajanje > 180 in < 365 dni) pogodb v posamezni kategoriji

-- najprej napolnim po en zapis za vsak mesec v zahtevanem obdobju ter za vse kategorije
INSERT INTO report_sql (computer, NUM1, NUM2, STR1, str2, str3, num3, num19, num4, num5, num6, num7, num8, num9, num14, num15, num16, num17)
SELECT distinct {?computer}, 
       extract (month from ({?Datum_od} + rownum - 1)) num_mesec, 
       extract (year from ({?Datum_od} + rownum - 1)) num_leto, 
       to_char(({?Datum_od} + rownum - 1),'Mon') str_mesec, m_nnkateg.opis, m_nnkateg.sifra, m_nnkateg.sort, 1,
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0
FROM   all_objects
LEFT OUTER JOIN m_nnkateg ON 1=1
WHERE  rownum <= {?Datum_do} - {?Datum_od} +1
AND m_nnkateg.sifra_sklopa='AL'
;

-- prvi in zadnji dan posameznega meseca
UPDATE report_sql SET date1=to_date('01.' || to_char(num1,'99') || '.' || to_char(num2,'9999'),'dd.mm.yyyy')
WHERE computer={?computer};

UPDATE report_sql SET date2=last_day(date1)
WHERE computer={?computer};

-- pomoni zapisi za tetje po mesecih in kategorijah - nove + podaljanja
INSERT INTO report_sql (computer, num1, num2, date1, date2, str1, num3, num19)
SELECT {?computer}, p1.id_plovila, p1.id_pogodbe, p1.datum_zacetka, CASE WHEN p1.datum_konca IS NULL THEN p1.datum_zacetka + 365 ELSE p1.datum_konca END,
       m_nnkateg.sifra,
       (SELECT count(*) 
               FROM m_pogodbe p2 
               WHERE p1.id_plovila=p2.id_plovila and p2.datum_zacetka < p1.datum_zacetka and p2.id_pogodbe <> p1.id_pogodbe), 2
FROM m_pogodbe p1
JOIN plovila p ON p1.Id_plovila=p.ID
JOIN m_nnkateg ON p.dolzina <= m_nnkateg.range_to AND p.dolzina >= m_nnkateg.range_from AND m_nnkateg.sifra_sklopa='AL'
WHERE p1.datum_zacetka BETWEEN {?Datum_od} AND {?Datum_do};


-- pomoni zapisi za tetje po mesecih in kategorijah - potekle
INSERT INTO report_sql (computer, num1, num2, date1, date2, str1, num3, num19)
SELECT {?computer}, p1.id_plovila, p1.id_pogodbe, p1.datum_zacetka, CASE WHEN p1.datum_konca IS NULL THEN p1.datum_zacetka + 365 ELSE p1.datum_konca END, 
       m_nnkateg.sifra, 
       (SELECT count(*)
        FROM m_pogodbe p2
        WHERE p1.id_plovila=p2.id_plovila and p2.datum_zacetka >= p1.datum_zacetka and p2.id_pogodbe <> p1.id_pogodbe and p2.status<>'R'), 3
FROM m_pogodbe p1
JOIN plovila p ON p1.Id_plovila=p.ID
JOIN m_nnkateg ON p.dolzina <= m_nnkateg.range_to AND p.dolzina >= m_nnkateg.range_from AND m_nnkateg.sifra_sklopa='AL'
WHERE p1.datum_konca BETWEEN {?Datum_od} AND {?Datum_do}
AND p1.status <> 'R';

-- pomoni zapisi za tetje po mesecih in kategorijah - prekinitve
INSERT INTO report_sql (computer, num1, num2, date1, date2, date3, str1, num3, num19)
SELECT {?computer}, p1.id_plovila, p1.id_pogodbe, p1.datum_zacetka, CASE WHEN p1.datum_konca IS NULL THEN p1.datum_zacetka + 365 ELSE p1.datum_konca END,  
       p1.datum_prekinitve, m_nnkateg.sifra, 
       (SELECT count(*)
        FROM m_pogodbe p2
        WHERE p1.id_plovila=p2.id_plovila and p2.datum_zacetka >= p1.datum_zacetka and p2.id_pogodbe <> p1.id_pogodbe and p2.status<>'R'), 5
FROM m_pogodbe p1
JOIN plovila p ON p1.Id_plovila=p.ID
JOIN m_nnkateg ON p.dolzina <= m_nnkateg.range_to AND p.dolzina >= m_nnkateg.range_from AND m_nnkateg.sifra_sklopa='AL'
WHERE p1.datum_prekinitve BETWEEN {?Datum_od} AND {?Datum_do}
AND p1.status ='R';

-- tevilo novih letnih pogodb v posamezni kategoriji (tevilo prejnjih pogodb za isto plovilo = 0)
UPDATE report_sql r1 SET r1.NUM4=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date1 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 = 0
       AND r2.date2 - r2.date1 >= 365
       AND r2.str1 = r1.str3
       AND r2.num19 = 2)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo podaljanih letnih pogodb v posamezni kategoriji (tevilo prejnjih pogodb za isto plovilo > 0)
UPDATE report_sql r1 SET r1.NUM5=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date1 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 > 0
       AND r2.date2 - r2.date1 >= 365
       AND r2.str1 = r1.str3
       AND r2.num19 = 2)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo poteklih letnih pogodb v posamezni kategoriji (status <> 'R'; tevilo novejih pogodb za isto plovilo = 0)
UPDATE report_sql r1 SET r1.NUM6=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date2 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 = 0
       AND r2.date2 - r2.date1 >= 365
       AND r2.str1 = r1.str3
       AND r2.num19 = 3)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo prekinjenih letnih pogodb v posamezni kategoriji (status='R'; tevilo novejih pogodb za isto plovilo = 0)
UPDATE report_sql r1 SET r1.NUM7=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date3 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 = 0
       AND r2.date2 - r2.date1 >= 365
       AND r2.str1 = r1.str3
       AND r2.num19 = 5)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo novih sezonskih pogodb v posamezni kategoriji (tevilo prejnjih pogodb za isto plovilo = 0)
UPDATE report_sql r1 SET r1.NUM14=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date1 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 = 0
       AND r2.date2 - r2.date1 BETWEEN 181 AND 364
       AND r2.str1 = r1.str3
       AND r2.num19 = 2)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo podaljanih sezonskih pogodb v posamezni kategoriji (tevilo prejnjih pogodb za isto plovilo > 0)
UPDATE report_sql r1 SET r1.NUM15=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date1 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 > 0
       AND r2.date2 - r2.date1 BETWEEN 181 AND 364
       AND r2.str1 = r1.str3
       AND r2.num19 = 2)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo poteklih sezonskih pogodb v posamezni kategoriji (status <> 'R')
UPDATE report_sql r1 SET r1.NUM16=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date2 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 = 0
       AND r2.date2 - r2.date1 BETWEEN 181 AND 364
       AND r2.str1 = r1.str3
       AND r2.num19 = 3)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- tevilo prekinjenih sezonskih pogodb v posamezni kategoriji (status='R')
UPDATE report_sql r1 SET r1.NUM17=(
       SELECT count(*)
       FROM report_sql r2
       WHERE r1.computer=r2.computer
       AND r2.date3 BETWEEN r1.date1 AND r1.date2
       AND r2.num3 = 0
       AND r2.date2 - r2.date1 BETWEEN 181 AND 364
       AND r2.str1 = r1.str3
       AND r2.num19 = 5)
WHERE r1.computer = {?computer} AND r1.num19=1;

-- LAPSE rate za annual
INSERT INTO report_sql (computer, NUM1, NUM2, STR1, num8, date1, date2, num19, str2, str3, num3, num4, num5, num6, num7, num9, num14, num15, num16, num17)
SELECT computer, num1, num2, str1, CASE WHEN sum(num5) = 0 THEN 0 ELSE (sum(num6) + sum(num7)) / sum(num5) * 100 END, date1, date2, 1, 'Up to 6m', '99', 
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0
FROM report_sql
WHERE computer={?computer} AND num19=1
GROUP BY computer, num1, num2, str1, date1, date2;

-- LAPSE RATE Annual Total
INSERT INTO report_sql (computer, NUM1, NUM2, STR1, num8, date1, date2, num19, str2, str3, num3, num4, num5, num6, num7, num9, num14, num15, num16, num17)
SELECT computer, 12, 2999, 'Dec', CASE WHEN sum(num5) = 0 THEN 0 ELSE (sum(num6) + sum(num7)) / sum(num5) * 100 END, 
       to_date('01.12.2299','dd.mm.yyyy'), max(date1), 1, 'Up to 6m', '99', 
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0
FROM report_sql
WHERE computer={?computer} AND num19=1 and str3 <> '99'
GROUP BY computer;

-- LAPSE rate za seasonal
INSERT INTO report_sql (computer, NUM1, NUM2, STR1, num9, date1, date2, num19, str2, str3, num3, num4, num5, num6, num7, num8, num14, num15, num16, num17)
SELECT computer, num1, num2, str1, CASE WHEN sum(num15) = 0 THEN 0 ELSE (sum(num16) + sum(num17)) / sum(num15) * 100 END, date1, date2, 1, 'Up to 6m', '99', 
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0
FROM report_sql
WHERE computer={?computer} AND num19=1
GROUP BY computer, num1, num2, str1, date1, date2;

-- LAPSE RATE Seasonal Total
INSERT INTO report_sql (computer, NUM1, NUM2, STR1, num9, date1, date2, num19, str2, str3, num3, num4, num5, num6, num7, num8, num14, num15, num16, num17)
SELECT computer, 12, 2999, 'Dec', CASE WHEN sum(num15) = 0 THEN 0 ELSE (sum(num16) + sum(num17)) / sum(num15) * 100 END, 
       to_date('01.12.2299','dd.mm.yyyy'), max(date1), 1, 'Up to 6m', '99', 
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0
FROM report_sql
WHERE computer={?computer} AND num19=1 and str3 <> '99'
GROUP BY computer;

-- Churn - total
INSERT INTO report_sql (computer, str2, str3, num3, num4, num5, num6, num14, num15, num16, num19)
SELECT computer, str2, str3, num3, sum(num4), sum(num5), sum(num6) + sum(num7), sum(num14), sum(num15), sum(num16) + sum(num17), 4
FROM report_sql
WHERE computer={?computer} AND num19=1 and str3 <> '99'
GROUP BY computer, str2, str3, num3;