DELETE FROM report_sql WHERE computer={?computer};

-- NUM1  numerini mesec
-- NUM2  leto
-- STR1  3-mestni naziv meseca
-- DATE1 prvi dan meseca
-- DATE2 zadnji dan meseca
-- DATE3 dan (za vsak dan v obdobju en zapis)
-- NUM20 tevilo dni v mesecu
-- STR2  kategorija
-- STR3  ifra kategorije
-- NUM3  sort iz M_NNKATEG
-- NUM4  tevilo privezov v posamezni kategoriji
-- NUM5  tevilo prodanih dni (count iz m_storitve_income) po kategorijah
-- NUM6  tevilo dni na razpolago (num4 * num20)
-- NUM19 vrsta zapisa (1=po dnevih, osnova za izraun; 2=po mesecih, osnova za izpis)

-- najprej napolnim po en zapis za vsak dan v zahtevanem obdobju ter tevilo zasedenih privezov za vse kategorije

INSERT INTO report_sql (computer, date3, str2, str3, num3, num5, num19)
SELECT {?computer}, d.datum, m_nnkateg.opis, m_nnkateg.sifra, m_nnkateg.sort, count(distinct r.id_privez), 1
FROM rezervac_detail r
JOIN nnprivez ON r.id_privez=nnprivez.id_privez
JOIN m_nnkateg ON nnprivez.dolzina <= m_nnkateg.range_to AND nnprivez.dolzina >= m_nnkateg.range_from AND m_nnkateg.sifra_sklopa='AL'
LEFT OUTER JOIN (SELECT {?Datum_od} + rownum -1 datum
                 FROM   all_objects
                 WHERE  rownum <= {?Datum_do} - {?Datum_od} +1) d ON 1=1
WHERE r.status_rezervac in (0,1)
AND (r.datum_od < d.datum and r.datum_do > d.datum or
     r.datum_od = r.datum_do and r.datum_od = d.datum)
GROUP BY {?computer}, d.datum, m_nnkateg.opis, m_nnkateg.sifra, m_nnkateg.sort
;   

-- mesec, leto
UPDATE report_sql SET num1=extract(month FROM date3), num2=extract(year FROM date3), str1=to_char(date3,'Mon')
WHERE computer={?computer};

-- prvi in zadnji dan posameznega meseca
UPDATE report_sql SET date1=to_date('01.' || to_char(num1,'99') || '.' || to_char(num2,'9999'),'dd.mm.yyyy')
WHERE computer={?computer};

UPDATE report_sql SET date2=last_day(date1)
WHERE computer={?computer};

-- sumiranje vrstic po mesecih in kategorijah = tevilo zasedenih dni
INSERT INTO report_sql (computer, num1, num2, str1, str2, str3, num3, num5, date1, date2, num19)
SELECT computer, num1, num2, str1, str2, str3, num3, sum(num5), date1, date2, 2
FROM report_sql
WHERE computer={?computer} AND num19=1
GROUP BY computer, num1, num2, str1, str2, str3, num3, date1, date2;

-- pobriem detaljne vrstice, za report rabim samo sume
delete from report_sql
WHERE computer={?computer} AND num19=1;

-- tevilo dni v mesecu
UPDATE report_sql SET num20=date2-date1+1
WHERE computer={?computer};

-- tevilo privezov v posamezni kategoriji
UPDATE report_sql SET NUM4=(
       SELECT count(*)
       FROM nnprivez
       JOIN m_nnkateg ON nnprivez.dolzina <= m_nnkateg.range_to AND nnprivez.dolzina >= m_nnkateg.range_from AND m_nnkateg.sifra_sklopa='AL'
       WHERE occupancy_statistics='Y' AND nvl(dolzina,0) > 0
       AND m_nnkateg.sifra=report_sql.str3)
WHERE computer={?computer};

UPDATE report_sql SET num5=0
WHERE computer={?computer} AND num5 IS NULL;

-- tevilo dni na razpolago
UPDATE report_sql SET num6 = num4 * num20
WHERE computer={?computer};

-- total
INSERT INTO report_sql (computer, str1, str2, str3, num1, num2, num3, num5, num6, date1, date2)
SELECT computer, str1, 'Total', '98', num1, num2, 98, sum(num5), sum(num6), date1, date2
FROM report_sql
WHERE computer={?computer}
GROUP BY computer, str1, num1, num2, date1, date2;

-- YTD Occupancy (kumulativa)
INSERT INTO report_sql (computer, str1, str2, str3, num1, num2, num3, num5, num6, date1, date2)
SELECT r.computer, r.str1, 'YTD Occupancy', '99', r.num1, r.num2, 99, 
       (SELECT sum(r1.num5) FROM report_sql r1 WHERE r1.computer=r.computer AND r1.num1 <= r.num1) num5, 
       (SELECT sum(r1.num6) FROM report_sql r1 WHERE r1.computer=r.computer AND r1.num1 <= r.num1) num6,  
       r.date1, r.date2
FROM report_sql r
WHERE r.computer={?computer}
GROUP BY r.computer, r.str1, r.num1, r.num2, r.date1, r.date2;

