DELETE FROM report_sql WHERE computer={?computer};

-- NUM1  numerini mesec
-- NUM2  leto
-- STR1  3-mestni naziv meseca
-- DATE1 prvi dan meseca
-- DATE2 zadnji dan meseca
-- NUM20 tevilo dni v mesecu
-- STR2  kategorija
-- STR3  ifra kategorije
-- NUM3  sort iz M_NNKATEG
-- NUM4  tevilo privezov v posamezni kategoriji
-- NUM5  tevilo prodanih dni (count iz m_storitve_income) po kategorijah
-- NUM6  tevilo dni na razpolago (num4 * num20)
-- NUM11 procent zasedenosti (dejansko tevilo plaanih dni iz m_storitve_income / tevilo dni na razpolago)

-- najprej napolnim po en zapis za vsak mesec v zahtevanem obdobju ter za vse kategorije
INSERT INTO report_sql (computer, NUM1, NUM2, STR1, str2, str3, num3)
SELECT distinct {?computer}, 
       extract (month from ({?Datum_od} + rownum - 1)) num_mesec, 
       extract (year from ({?Datum_od} + rownum - 1)) num_leto, 
       to_char(({?Datum_od} + rownum - 1),'Mon') str_mesec, m_nnkateg.opis, m_nnkateg.sifra, m_nnkateg.sort
FROM   all_objects
LEFT OUTER JOIN m_nnkateg ON 1=1
WHERE  rownum <= {?Datum_do} - {?Datum_od} +1
AND m_nnkateg.sifra_sklopa='AL'
;

-- prvi in zadnji dan posameznega meseca
UPDATE report_sql SET date1=to_date('01.' || to_char(num1,'99') || '.' || to_char(num2,'9999'),'dd.mm.yyyy')
WHERE computer={?computer};

UPDATE report_sql SET date2=last_day(date1)
WHERE computer={?computer};

UPDATE report_sql SET num20=date2-date1+1
WHERE computer={?computer};

-- tevilo privezov v posamezni kategoriji
UPDATE report_sql SET NUM4=(
       SELECT count(*)
       FROM nnprivez
       JOIN m_nnkateg ON nnprivez.dolzina <= m_nnkateg.range_to AND nnprivez.dolzina >= m_nnkateg.range_from AND m_nnkateg.sifra_sklopa='AL'
       WHERE occupancy_statistics='Y' AND nvl(dolzina,0) > 0
       AND m_nnkateg.sifra=report_sql.str3)
WHERE computer={?computer};

-- tevilo prodanih dni

UPDATE report_sql SET num5=(
       SELECT nvl(sum(count(distinct msi.datum) * CASE WHEN r.znesek < 0 THEN -1 ELSE 1 END),0)
       FROM racun_data r
       JOIN m_storitve m ON r.Id_Storitve=m.Id_Storitve
       JOIN m_storitve_income msi ON m.Id_Storitve=msi.Id_Storitve
       JOIN m_nnstomar ms ON m.Storitev=ms.Sifra
       JOIN saldkont s ON r.Id_Saldkont=s.Id_saldkont
       JOIN kupci k ON s.Id_kupca = k.id
       JOIN plovila p ON s.Id_Plovila=p.Id
       LEFT OUTER JOIN nnprivez n ON (CASE WHEN m.Id_privez IS NULL THEN msi.Id_privez ELSE m.Id_Privez END)= n.Id_privez
       LEFT OUTER JOIN m_nnkateg k ON n.dolzina <= k.range_to AND n.dolzina >= k.range_from AND k.sifra_sklopa='AL'
       WHERE ms.Berth_Income = 'Y'       
       AND m.Datum_od <> m.Datum_do
       AND msi.Datum BETWEEN report_sql.date1 AND report_sql.date2
       AND k.Sifra=report_sql.str3
-- tole bi bilo treba vkljuiti za storitve brez kategorije (a dela dolgo)
--       AND CASE WHEN k.Sifra IS NULL THEN k1.Sifra ELSE k.Sifra END=report_sql.str3)
       GROUP BY (CASE WHEN m.Id_privez IS NULL THEN msi.Id_privez ELSE m.Id_Privez END), r.n_racuna, r.znesek
       )
WHERE computer={?computer};

UPDATE report_sql SET num5=0
WHERE computer={?computer} AND num5 IS NULL;

-- tevilo dni na razpolago
UPDATE report_sql SET num6 = num4 * num20
WHERE computer={?computer};

-- total
INSERT INTO report_sql (computer, str1, str2, str3, num1, num2, num3, num5, num6, date1, date2)
SELECT computer, str1, 'Total', '98', num1, num2, 98, sum(num5), sum(num6), date1, date2
FROM report_sql
WHERE computer={?computer}
GROUP BY computer, str1, num1, num2, date1, date2;

-- YTD Occupancy (kumulativa)
INSERT INTO report_sql (computer, str1, str2, str3, num1, num2, num3, num5, num6, date1, date2)
SELECT r.computer, r.str1, 'YTD Occupancy', '99', r.num1, r.num2, 99, 
       (SELECT sum(r1.num5) FROM report_sql r1 WHERE r1.computer=r.computer AND r1.num1 <= r.num1) num5, 
       (SELECT sum(r1.num6) FROM report_sql r1 WHERE r1.computer=r.computer AND r1.num1 <= r.num1) num6,  
       r.date1, r.date2
FROM report_sql r
WHERE r.computer={?computer}
GROUP BY r.computer, r.str1, r.num1, r.num2, r.date1, r.date2;

