DELETE FROM report_sql WHERE computer={?computer};

-- STR1  kupci.int_code
-- STR2  naziv kupca
-- STR3  ime plovila
-- NUM1  dolina plovila
-- NUM2  dolina priveza
-- STR4  t. zadnjega rauna, ki vseuje storitev TRA ali ABR
-- STR5  objekt
-- STR6  pomol
-- STR7  trenutni privez
-- STR8  pogodbeni privez
-- DATE1 trenutno od
-- DATE2 trenutno do oz. pogodba do
-- STR9  tip Short term/Long term, odvisno ali ima plovilo pogodbo
-- NUM3  zaraunani znesek (zadnji raun)
-- STR10 status priveza (zaseden, prost, prost a ima pogodbo)
-- NUM4  sort
-- STR11 naziv objekta

INSERT INTO report_sql (computer, STR1, STR2, STR3, NUM1, NUM2, STR4, STR5, STR6, STR7, STR8, 
                        DATE1, DATE2, STR9, NUM3, STR10, NUM4, STR11)
SELECT {?computer},
       kupci.int_code AS customer_no,
       trim(kupci.priimek || ' ' || kupci.ime) AS name, 
       plovila.ime AS boat_name,
       plovila.dolzina AS boat_size,
       pod.dolzina AS berth_size,
       (SELECT n_racuna FROM saldkont WHERE id_saldkont = 
               (SELECT max(saldkont.id_saldkont) FROM saldkont
                JOIN racun_data ON saldkont.id_saldkont=racun_data.id_saldkont
                JOIN m_storitve on racun_data.id_storitve=m_storitve.id_storitve
                WHERE saldkont.storno IS null
                AND m_storitve.storitev in ('TRA', 'ABR')
                AND saldkont.id_kupca=kupci.id)
       ) invoice_nr,
       nnobjekt.sifra AS marina,
       nnpomol.naziv AS pier,
       pod.n_priveza AS berth,
       plovila.pogodbena_n_priveza AS contract_berth,
       plovila.trenutno_od AS berthing_from,
       nvl(plovila.trenutno_do, plovila.pogodba_do) AS berthing_to,
       CASE WHEN plovila.id IS NULL THEN NULL
            ELSE CASE WHEN plovila.pogodbena_n_priveza IS NULL THEN 'Short Term' ELSE 'Long Term' END 
       END AS berth_duration,
       (SELECT znesek FROM saldkont WHERE id_saldkont = 
               (SELECT max(saldkont.id_saldkont) FROM saldkont
                JOIN racun_data ON saldkont.id_saldkont=racun_data.id_saldkont
                JOIN m_storitve on racun_data.id_storitve=m_storitve.id_storitve
                WHERE saldkont.storno IS null
                AND m_storitve.storitev in ('TRA', 'ABR')
                AND saldkont.id_kupca=kupci.id)
       ) amount,
       CASE WHEN plovila.id IS NOT NULL THEN 'Occupied'
            ELSE CASE WHEN pod.pogodba = 0 THEN 'Vacant, no contract' ELSE 'Vacant, under contract' END
       END AS berth_status,
       pod.sort,
       nnobjekt.opis AS marina_naziv
FROM (
SELECT nnprivez.id_privez, nnprivez.dolzina, nnprivez.objekt, nnprivez.n_priveza, nnprivez.kategorija, nnprivez.sort,
       (SELECT id_plovila FROM privezi WHERE id_privez=nnprivez.id_privez AND id_pogodbe IS NULL) plovilo,
       (SELECT count(*) FROM privezi WHERE id_privez=nnprivez.id_privez AND id_pogodbe IS NOT NULL) pogodba
FROM nnprivez) pod
LEFT OUTER JOIN plovila ON pod.plovilo=plovila.id
LEFT OUTER JOIN kupci ON plovila.id_lastnika=kupci.id
LEFT OUTER JOIN nnobjekt ON pod.objekt=nnobjekt.sifra
LEFT OUTER JOIN nnpomol ON pod.kategorija=nnpomol.sifra
;